#!/bin/bash

println() {
    level=$1
    text=$2

    if [ "$level" == "error" ]; then
        echo -en "\033[0;36;31m$text\033[0;38;39m\n\r"
    elif [ "$level" == "warn" ]; then
        echo -en "\033[0;36;33m$text\033[0;38;39m\n\r"
    else
        echo -en "\033[0;36;40m$text\033[0;38;39m\n\r"
    fi
}

ask_yn_question()
{
        QUESTION=$1

        while true;
        do
                echo -en "${QUESTION} (y/n) "
                read REPLY
                if [ "${REPLY}" == "y" ];
                then
                        return 0;
                fi
                if [ "${REPLY}" == "n" ];
                then
                        return 1;
                fi
                echo "Don't tell ya life, reply using 'y' or 'n'"'!'
        done
}

println info "Install reverse SSH dialplan and script"
println info "\n"
println info "STEP 1: Copying files"
println info "\t-- dialplan :"
println info "\tcp -a reverse-ssh-dialplan.conf /etc/asterisk/extensions_extra.d/"

if [ -e /etc/asterisk/extensions_extra.d/reverse-ssh-dialplan.conf ]; then
    println warn "\tFile /etc/asterisk/extensions_extra.d/reverse-ssh-dialplan.conf already exists."
    if ! ask_yn_question "\tWould you like to replace it ?"; then
        println error "\tFile not replaced. Exiting"
        exit 1
    fi
fi
cp -af reverse-ssh-dialplan.conf /etc/asterisk/extensions_extra.d/
chown root:root /etc/asterisk/extensions_extra.d/reverse-ssh-dialplan.conf
chmod 664 /etc/asterisk/extensions_extra.d/reverse-ssh-dialplan.conf

println info "\t-- script :"
println info "\tcp -a reverse-ssh-script.sh /usr/local/sbin/"

if [ -e /usr/local/sbin/reverse-ssh-script.sh ]; then
    println warn "\tFile /usr/local/sbin/reverse-ssh-script.sh already exists."
    if ! ask_yn_question "\tWould you like to replace it ?"; then
        println error "\tFile not replaced. Exiting"
        exit 1
    fi
fi
cp -af reverse-ssh-script.sh /usr/local/sbin/
chown root:root /usr/local/sbin/reverse-ssh-script.sh
chmod 775 /usr/local/sbin/reverse-ssh-script.sh

println info "\t-- sound files :"

for file in $(ls -1 *.wav); do
    println info "\tcp -a $file /var/lib/xivo/sounds/playback/"
    if [ -e /var/lib/xivo/sounds/playback/$file ]; then
        println warn "\tFile /var/lib/xivo/sounds/playback/$file already exists."
        if ! ask_yn_question "\tWould you like to replace it ?"; then
            println error "\tFile not replaced. Exiting"
            exit 1
        fi
    fi
    cp -af $file /var/lib/xivo/sounds/playback/
    chown asterisk:www-data /var/lib/xivo/sounds/playback/$file
    chmod 660 /var/lib/xivo/sounds/playback/$file
done

println info "\n"
if ! ask_yn_question "\tType y when you're ready to continue on STEP 2"; then
    println error "\tSTEP 2 wasn't completed."
    exit 1
fi
println info "\n"

println info "STEP 2: Configuring dialplan"
println info "\tYou now have to add a DID with :"
println info "\t\tDestination : Personalized"
println info "\t\tCommand : Goto(support-reverse-ssh|s|1)"
println info "\tThis will permit you to open the reverse SSH by calling this DID"
println info "\n"
if ! ask_yn_question "\tType y when you're ready to continue on STEP 3"; then
    println error "\tSTEP 3 wasn't completed."
    exit 1
fi
println info "\n"

println info "STEP 3: Configuring the sudoers"
println info "\tYou now have to add a the right to user asterisk to use the script"
println info "\tAdd or Modify a line like this :"
println info "\t\tasterisk        ALL=(root) NOPASSWD:/usr/sbin/arping,/usr/local/sbin/reverse-ssh-script.sh"
println info "\n"
if ! ask_yn_question "\tType y when you're ready to continue on STEP 4"; then
    println error "\tSTEP 4 wasn't completed."
    exit 1
fi
println info "\n"

println info "STEP 4: Applying configuration"
if ! ask_yn_question "\tWould you like to reload asterisk dialplan ?"; then
    println warn "\tAsterisk dialplan was NOT reloaded."
else
    /usr/sbin/asterisk -rx 'dialplan reload'
    println info "\tAsterisk dialplan was reloaded."
fi

println info "\n"
println info "Installation finished"

