#!/bin/bash
# This script :
#  - opens an SSH connexion with the user specified as the 1st parameter,
#  - towards a remote server specified as the 2nd parameter,
#  - forwarding the local SSH port (TCP/22)
#  - towards the remote port specified as the 3rd parameter
#  - and executing the command "sleep 28800" (it will then close the connexion after 8hours)
#  - ssh will exit if the port forwarding failed (e.g. if remote port is already used)
#
# Note that, to be able to execute it via the dialplan, you need 
#  to launch it with the 'sudo' command via the 'System' application
#  and therefore to add this script to the sudoers file like this :
#  asterisk        ALL=(root) NOPASSWD:/usr/sbin/arping,/usr/local/sbin/reverse-ssh-script.sh


if [ $# -ne 3 ]; then
    echo "== Init reverse ssh connexion for XiVO management =="
    echo "Usage : $0 <user> <server> <ssh_port>"
    echo "e.g. : $0 client janine.avencall.com 50010"
    exit 1
fi

rm /tmp/reverse-ssh.out
/usr/bin/ssh -oExitOnForwardFailure=yes -f -R $3:localhost:22 $1@$2 sleep 28800 2> /tmp/reverse-ssh.out

# Sleep needed because the ExitOnForwardFailure does not give an immediate result
# in stderr. Therefore we wait 2 seconds to be sure that /tmp/reverse-ssh.out will contain the
# error message - then the test below will be consistent.
sleep 2

# If /tmp/reverse-ssh.out exists and not void, exit with status code 1 (failure)
test -s /tmp/reverse-ssh.out && exit 1
# Otherwise, exit with status code 0 (success)
exit 0

